@@ -36,6 +36,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "package",
     // ↓ Toolchain version modules ↓
     // (Let's keep these sorted alphabetically)
+    "bun",
     "c",
     "cmake",
     "cobol",
@@ -99,7 +100,7 @@ pub const PROMPT_ORDER: &[&str] = &[
 ];
 
 // On changes please also update `Default` for the `FullConfig` struct in `mod.rs`
-impl<'a> Default for StarshipRootConfig {
+impl Default for StarshipRootConfig {
     fn default() -> Self {
         Self {
             schema: "https://starship.rs/config-schema.json".to_string(),
